package com.jz.dmp.modules.controller.DataIntegration;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.SourceDbNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.TaskListPageDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.TaskListPageReq;
import com.jz.dmp.modules.service.OfflineSynchService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:离线同步
 * @ClassName: OfflineSynchController
 * @Author Bellamy
 * @Date 2020/12/20
 */
@RestController
@RequestMapping("/offlineSynch")
@Api(tags = "数据集成--离线同步")
public class OfflineSynchController {

    @Autowired
    private OfflineSynchService offlineSynchService;

    /**
     * 任务列表分页查询
     *
     * @return
     */
    @ApiOperation(value = "任务列表分页查询", notes = "任务列表分页查询")
    @PostMapping(value = "/taskListPage")
    public PageInfoResponse<TaskListPageDto> getTaskListPage(@RequestBody @Validated TaskListPageReq taskListPageReq) {
        PageInfoResponse<TaskListPageDto> pageInfo = new PageInfoResponse<TaskListPageDto>();
        try {
            pageInfo = offlineSynchService.queryTaskListPage(taskListPageReq);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 获取源数据库名称——下拉框
     *
     * @return
     */
    @ApiOperation(value = "获取源数据库名称-下拉框", notes = "获取源数据库名称")
    @GetMapping(value = "/sourceDbList")
    @ApiImplicitParam(name = "projectId", value = "项目id")
    public JsonResult<List<SourceDbNameListDto>> getSourceDbList(@RequestParam Integer projectId) throws Exception {
        JsonResult<List<SourceDbNameListDto>> jsonResult = offlineSynchService.querygSourceDbList(projectId);
        return jsonResult;
    }

    /**
     * 根据源数据库id,获取源数据表——下拉框
     *
     * @return
     */
    @ApiOperation(value = "根据源数据库id,获取源数据表-下拉框", notes = "根据源数据库id,获取源数据表")
    @GetMapping(value = "/sourceTableList")
    @ApiImplicitParam(name = "sourceDbId", value = "源数据库id")
    public JsonResult getSourceTableList(@RequestParam Integer sourceDbId,@RequestParam(value = "targetName", required = false) String targetName) throws Exception {
        List<Map> list = offlineSynchService.querygSourceTableList(sourceDbId,targetName);
        return new JsonResult(ResultCode.SUCCESS, list);
    }
}
